.. _frequency_domain:

Frequency Domain Models
=======================

In order to simplify computation and model design, the frequency domain models only consider a single frequency of interest, useful for narrow band performance evaluations.

.. automodule:: lyceanem.models.frequency_domain
    :members: aperture_projection, calculate_farfield, calculate_scattering

